@@ -91,7 +91,7 @@ def start_testbed(args, temp_dir, no_clean_on_error=False, host_distro=None):
         pass
     except BaseException as e:
         if no_clean_on_error:
-            logger.warn("preserving temporary files in: %s", testbed.scratch)
+            logger.warning("preserving temporary files in: %s", testbed.scratch)
             should_clean = False
         raise
     finally:
@@ -545,7 +545,8 @@ def cli_parser():
 
     group1 = parser.add_argument_group('basic options')
     group1.add_argument('--verbosity', type=int, default=0,
-        help='An integer.  Control which messages are displayed.')
+        help='An integer. Control which messages are displayed (0: quiet ('
+             'warning/error only), 1: info, 2: debug).')
     group1.add_argument('-v', '--verbose', dest='verbosity', action='count',
         help='Like --verbosity, but given multiple times without arguments.')
     group1.add_argument('--host-distro', default=None,
@@ -689,7 +690,7 @@ def command_line(parser, argv):
 def get_main_spec(parsed_args):
     variations = [parsed_args.variations] + parsed_args.vary
     if parsed_args.dont_vary:
-        logger.warn("--dont-vary is deprecated; use --vary=-$variation instead")
+        logger.warning("--dont-vary is deprecated; use --vary=-$variation instead")
         variations += ["-%s" % a for x in parsed_args.dont_vary for a in x.split(",")]
     return VariationSpec().extend(variations)
 
@@ -731,9 +732,9 @@ def run(argv, dry_run=None):
         elif first_arg == "auto":
             build_command = first_arg
             if parsed_args.artifact_pattern:
-                logger.warn("old CLI form `reprotest auto <source_root>` detected, "
+                logger.warning("old CLI form `reprotest auto <source_root>` detected, "
                     "setting source_root to the second argument: %s", parsed_args.artifact_pattern)
-                logger.warn("to avoid this warning, use instead `reprotest <source_root>` "
+                logger.warning("to avoid this warning, use instead `reprotest <source_root>` "
                     "or (if really necessary) `reprotest -s <source_root> auto <artifact>`")
                 source_root = parsed_args.artifact_pattern
                 parsed_args.artifact_pattern = None
@@ -743,7 +744,7 @@ def run(argv, dry_run=None):
             parts = shlex.split(first_arg)
             if len(parts) == 1:
                 if shutil.which(parts[0]) is None:
-                    logger.warn("XXX")
+                    logger.warning("XXX")
                     raise RuntimeError("Not found, neither as a file nor as a command: %s" % first_arg)
             # if len(parts) > 1 then it could be something like '( command )'
             # which is valid despite '(' not existing.
@@ -792,7 +793,7 @@ def run(argv, dry_run=None):
             specs.append(spec.extend(extra_build))
         check_func = check
     if parsed_args.min_cpus is None and not dry_run:
-        logger.warn("The control build runs on 1 CPU by default, give --min-cpus to increase this.")
+        logger.warning("The control build runs on 1 CPU by default, give --min-cpus to increase this.")
     min_cpus = parsed_args.min_cpus or 1
     build_variations = Variations.of(
         *specs,
@@ -810,10 +811,10 @@ def run(argv, dry_run=None):
         missing = [(var, tools) for var, tools in missing if tools]
         for var, tools in missing:
             if tools:
-                logger.warn("Varying '%s' requires these program(s): %s", var, ", ".join(tools))
+                logger.warning("Varying '%s' requires these program(s): %s", var, ", ".join(tools))
         if missing:
-            logger.warn("Your build will probably fail, either install them or disable the variations.")
-            logger.warn("(From a system package manager, simply install the 'optional' or 'recommended' "
+            logger.warning("Your build will probably fail, either install them or disable the variations.")
+            logger.warning("(From a system package manager, simply install the 'optional' or 'recommended' "
                          "dependencies of reprotest.)")
 
     # Remaining args
